drop table department cascade constraints;

drop table part cascade constraints;

drop table repairstaff cascade constraints;

drop table partitem cascade constraints;

drop table customer cascade constraints;

drop table workorder cascade constraints;

drop table manager cascade constraints;

drop table PartReorder cascade constraints;

drop sequence partOrder;

CREATE SEQUENCE partOrder 
	start with  100001
	increment by 1
	maxvalue 999999
	minvalue  100001
	cycle;

CREATE TABLE Department 
(dName  VARCHAR(25) 	UNIQUE,
 dNum   NUMBER(4)		NOT NULL,
 phone  CHAR(10),
 type   VARCHAR(20),
        CONSTRAINT PK_Department PRIMARY KEY (dNum));

INSERT INTO Department VALUES ('computer', 1000, '2035551212', 'electronics');
INSERT INTO Department VALUES ('appliance', 1001, '2032341567', 'mechanical');
INSERT INTO Department VALUES ('television',  1002, '2035761111',  'electronics');
INSERT INTO Department VALUES ('Furniture', 1234, '2035769122', 'physical');

COMMIT;


CREATE TABLE Part
(pNum	NUMBER(6)    NOT NULL,
 name	VARCHAR2(25) DEFAULT 'WIDGET',
 info		VARCHAR2(25) NOT NULL,
 color	CHAR(6),
 qty		NUMBER(6)	DEFAULT 10,
 minQty	NUMBER(6)	DEFAULT 10,
 onOrder	NUMBER(6)	DEFAULT   0,
 cost		NUMBER(8,2)  DEFAULT 10000.00,
 weight	NUMBER(6,2) NOT NULL,
 dNum	NUMBER(4)	 NOT NULL,
          CONSTRAINT PK_Part   PRIMARY KEY (pNum, color),
	  CONSTRAINT CK_Part_COLOR CHECK (color IN ('BLUE', 'RED', 'SILVER', 'GREEN', 'BLACK', 'GRAY')),
          CONSTRAINT FK_Part_DEPT    FOREIGN KEY (dNum) REFERENCES Department );


INSERT INTO Part VALUES
(111111,'A/C cord', '110 volt power cord','BLACK',50, 20, 0,14.99, 1.3, 1000);
INSERT INTO Part VALUES
(111111,'A/C cord', '110 volt power cord','GREEN',50, 20, 0,14.99, 1.3, 1000);
INSERT INTO Part VALUES
(111112,'A/C cord', '220 volt power cord','GRAY',55, 25, 0,44.99, 2.7, 1001);
INSERT INTO Part VALUES
(111113,'switch', 'SONY S243','BLACK',150, 100, 0,9.99, 0.3, 1002);
INSERT INTO Part VALUES
(111113,'switch', 'SONY S243','GRAY',110, 100, 0,9.99, 0.3, 1002);
INSERT INTO Part VALUES
(111116,'switch', 'SONY S455b','BLACK',150, 120, 0,11.99, 0.2, 1002);
INSERT INTO Part VALUES
(111121,'switch', 'GE GE11a','BLACK', 20, 20, 0,24.99, 1.0, 1001);
INSERT INTO Part VALUES
(111132,'battery', '1.5 volt cell','SILVER',200, 190, 0,4.99, 0.1, 1000);
INSERT INTO Part VALUES
(111155,'rubber seal', 'GE washer','BLACK',5, 4, 0,20.00, 1.2, 1001);
INSERT INTO Part VALUES
(111881,'belt', 'MAYTAG MT33','BLUE',66, 50, 0,30.99, 0.8, 1001);
INSERT INTO Part VALUES
(111189,'monitor', 'HP 1200F','BLACK',34, 25, 0,199.99, 40.9, 1000);
INSERT INTO Part VALUES
(111189,'monitor', 'HP 1200F','GRAY',50, 45, 0,199.99, 40.9, 1000);
INSERT INTO Part VALUES
(111189,'monitor', 'HP 1200F','SILVER',15, 10, 0,199.99, 40.9, 1000);
INSERT INTO Part VALUES
(111366,'keyboard', 'SKB 580','BLACK',150, 125, 0,9.99, 2.8, 1000);
INSERT INTO Part VALUES
(112266,'50" plasma TV', 'PAN1100','BLACK',30, 25, 0,5500.00, 112.3, 1002);
INSERT INTO Part VALUES
(112266, '50" plasma TV', 'PAN1100','SILVER',29, 25,0, 5600.00, 112.3, 1002);


COMMIT;

CREATE TABLE PartReorder
(orderNum NUMBER(6),
 pNum	NUMBER(6)    NOT NULL,
 color	CHAR(6),
 qty		NUMBER(6)	DEFAULT 0,
          CONSTRAINT PK_PartReorder   PRIMARY KEY (orderNum),
	  CONSTRAINT CK_PartReorder_COLOR CHECK (color IN ('BLUE', 'RED', 'SILVER', 'GREEN', 'BLACK', 'GRAY')));



CREATE TABLE RepairStaff
(rNum        NUMBER(4)    NOT NULL,
 name        VARCHAR2(25) NOT NULL,
 hireDate    DATE,
 deptNum     NUMBER(4),
 salary      NUMBER(8,2),
             CONSTRAINT PK_RepairStaff   PRIMARY KEY (rNum), 
             CONSTRAINT UNIQUE_NAME      UNIQUE (name),
             CONSTRAINT FK_RepairStaff_DEPT FOREIGN KEY (deptNum)
					 REFERENCES DEPARTMENT );


 INSERT INTO RepairStaff VALUES
(3333, 'Barry Bonds', '12-JUN-2002', 1000, 32000);
INSERT INTO RepairStaff VALUES
(3344, 'Babe Ruth',  '15-MAY-2002', 1000, 36000);
INSERT INTO RepairStaff VALUES
(3365, 'Ed Jones',  '22-FEB-1998', 1001, 34000);
INSERT INTO RepairStaff VALUES
(2155 ,'Bill Allen',  '22-NOV-2002', 1000, 32000);
INSERT INTO RepairStaff VALUES
(1122 ,'Ann Smith', '09-SEP-1999', 1002, 29800);
INSERT INTO RepairStaff VALUES 
(6655, 'Ben Fenn',    '12-MAR-1994', 1001, 45900);
INSERT INTO RepairStaff VALUES
(5533,'Rob Bert',  '17-APR-1996', 1002, 42600);

COMMIT;


CREATE TABLE PartItem
(woNum	 NUMBER(8)    NOT NULL,
 pNum        NUMBER(6)    NOT NULL,
 serialNum   VARCHAR(25)  NOT NULL,
 color       CHAR(6),
       CONSTRAINT PK_PartItem PRIMARY KEY (woNum, pNum, serialNum),
       CONSTRAINT FK_PartItem_PNUM  FOREIGN KEY (pNum,color)
		REFERENCES Part,
       CONSTRAINT CK_PartItem_COLOR CHECK 
		(color IN ('BLUE', 'RED', 'SILVER', 'GREEN', 'BLACK', 'GRAY')) );

INSERT INTO PartItem VALUES
(10005000, 111111,'234543gfd35f5555','BLACK');
INSERT INTO PartItem VALUES
(10005000, 111111,'674543gfd35f5555','BLACK');
INSERT INTO PartItem VALUES
(10005001, 111111,'694543gfd35f5555','GREEN');
INSERT INTO PartItem VALUES
(10005002, 112266,'asf54m66g66d78k','SILVER');
INSERT INTO PartItem VALUES
(10005003, 112266,'abf54m56g66d54j','BLACK');
INSERT INTO PartItem VALUES
(10005004, 111155,'1345673342','BLACK');
INSERT INTO PartItem VALUES
(10005004, 111189,'23n45h33k45w','GRAY');
INSERT INTO PartItem VALUES
(10005005, 111189, '23y45n32q11v','BLACK');
INSERT INTO PartItem VALUES
(10005006, 111112,'11345622','GRAY');
INSERT INTO PartItem VALUES
(10005004, 111112,' 14346638','GRAY');

COMMIT;



 CREATE TABLE Customer
(cNum     		NUMBER(8)    NOT NULL,
 cName    		VARCHAR2(25) NOT NULL,
 cardNum  		CHAR(10)   NOT NULL,
 rNum     		NUMBER(4),
 contactDep	NUMBER(4),
          CONSTRAINT PK_Customer PRIMARY KEY (cNum),
          CONSTRAINT FK_Customer_CONTACTCEPT FOREIGN KEY (contactDep)
				       REFERENCES Department,
          CONSTRAINT FK_Customer_REPAIRSTAFFNUM FOREIGN KEY (rNum)
				       REFERENCES RepairStaff);


INSERT INTO Customer VALUES
(10000001,'Robert Johnson','1113332456',3333,1000);
INSERT INTO Customer VALUES
(10000002,'Tim Bartman','4573324569',3344,1000);
INSERT INTO Customer VALUES
(10000003,'Susan Saunders','7564797861',3365,1001);
INSERT INTO Customer VALUES
(10000004,'William Rothchild','4534465766',2155,1000);
INSERT INTO Customer VALUES
(10000005,'Anne Burton','5567781222',2155,1000);
INSERT INTO Customer VALUES
(10000006,'Fred Palmer','9877722310',6655,1001);
INSERT INTO Customer VALUES
(10000007,'Tina Wynn','0012300890',5533,1002);


COMMIT;

CREATE TABLE WorkOrder
(woNum       	NUMBER(8)	NOT NULL,
 wDesc         	VARCHAR(50)	NOT NULL,
 cNum		NUMBER(8)	NOT NULL,
 orderDate    	DATE,
 repairStaffNum  NUMBER(4)	NOT NULL,
             CONSTRAINT PK_WorkOrder PRIMARY KEY (woNum),
             CONSTRAINT FK_RepairStaff_RNUM FOREIGN KEY (repairStaffNum)
     						REFERENCES RepairStaff,
             CONSTRAINT FK_WorkOrder_CNUM FOREIGN KEY (cNum)
     						REFERENCES Customer);

INSERT INTO WorkOrder VALUES
(10005000, 'attach cords to 2 monitors', 10000001, '18-JAN-2002',6655);
INSERT INTO WorkOrder VALUES
(10005001, 'replace existing monitor cord', 10000003, '23-JAN-2002',1122);
INSERT INTO WorkOrder VALUES
(10005002, 'mount TV on wall - cust instruct where', 10000004, '06-JAN-2002',3333);
INSERT INTO WorkOrder VALUES
(10005003, 'set up TV on stand - remove old set', 10000005, '05-FEB-2002',3344);
INSERT INTO WorkOrder VALUES
(10005004, 'monitor in basement/install seal on GE washer', 10000007, '05-FEB-2002',2155);
INSERT INTO WorkOrder VALUES
(10005006, 'attach cord to monitor', 10000006, '06-FEB-2002',5533);
INSERT INTO WorkOrder VALUES
(10005005, 'check HP PC monitor/replace Dell monitor', 10000005, '07-FEB-2002',3365);

COMMIT;


CREATE TABLE Manager
(mNum	 NUMBER(4)  	NOT NULL,
 mName	VARCHAR(25)	NOT NULL,
 salary	NUMBER(8,2),
 dNum	NUMBER(4),
          CONSTRAINT PK_Manager PRIMARY KEY (mNum),
	  CONSTRAINT FK_Manager_DNUM FOREIGN KEY (dNum)
			REFERENCES Department,
          CONSTRAINT CK_Manager CHECK (salary >=  100000) );

INSERT INTO Manager 
VALUES (6000, 'Peter Fink', 123000.88, 1000);
INSERT INTO Manager 
VALUES (6001, 'Ellen Papa', 133000.238, 1001);
INSERT INTO Manager 
VALUES (6002, 'Cynthia Broda', 178000.76, 1002);
INSERT INTO Manager 
VALUES (6008, 'Julius Dichter', 222000.76, 1234);

COMMIT;


GRANT SELECT ON Department TO PUBLIC;
GRANT SELECT ON Part TO PUBLIC;
GRANT SELECT ON RepairStaff TO PUBLIC;
GRANT SELECT ON Customer TO PUBLIC;
GRANT SELECT ON WorkOrder TO PUBLIC;
GRANT SELECT ON Manager TO PUBLIC;
GRANT SELECT ON PartItem TO PUBLIC;

